km3pipe.core.Pipeline
=====================

.. currentmodule:: km3pipe.core

.. autoclass:: Pipeline

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Pipeline.__init__
      ~Pipeline.attach
      ~Pipeline.attach_bundle
      ~Pipeline.drain
      ~Pipeline.finish
   
   

   
   
   